@@ -3,9 +3,7 @@ from django.contrib import admin
 from .models import SESStat
 
 
+@admin.register(SESStat)
 class SESStatAdmin(admin.ModelAdmin):
     list_display = ('date', 'delivery_attempts', 'bounces', 'complaints',
                     'rejects')
-
-
-admin.site.register(SESStat, SESStatAdmin)
