@@ -4,3 +4,6 @@ from django.dispatch import Signal
 bounce_received = Signal()
 complaint_received = Signal()
 delivery_received = Signal()
+send_received = Signal()
+open_received = Signal()
+click_received = Signal()
